import type { OpenId4VciAccessTokenEndpointConfig, OpenId4VciCredentialEndpointConfig } from './router';
import type { AgentContext, Optional } from '@credo-ts/core';
import type { CNonceState, CredentialOfferSession, IStateManager, URIState } from '@sphereon/oid4vci-common';
import type { Router } from 'express';
export interface OpenId4VcIssuerModuleConfigOptions {
    /**
     * Base url at which the issuer endpoints will be hosted. All endpoints will be exposed with
     * this path as prefix.
     */
    baseUrl: string;
    /**
     * Express router on which the openid4vci endpoints will be registered. If
     * no router is provided, a new one will be created.
     *
     * NOTE: you must manually register the router on your express app and
     * expose this on a public url that is reachable when `baseUrl` is called.
     */
    router?: Router;
    endpoints: {
        credential: Optional<OpenId4VciCredentialEndpointConfig, 'endpointPath'>;
        accessToken?: Optional<OpenId4VciAccessTokenEndpointConfig, 'cNonceExpiresInSeconds' | 'endpointPath' | 'preAuthorizedCodeExpirationInSeconds' | 'tokenExpiresInSeconds'>;
    };
}
export declare class OpenId4VcIssuerModuleConfig {
    private options;
    readonly router: Router;
    private credentialOfferSessionManagerMap;
    private uriStateManagerMap;
    private cNonceStateManagerMap;
    constructor(options: OpenId4VcIssuerModuleConfigOptions);
    get baseUrl(): string;
    /**
     * Get the credential endpoint config, with default values set
     */
    get credentialEndpoint(): OpenId4VciCredentialEndpointConfig;
    /**
     * Get the access token endpoint config, with default values set
     */
    get accessTokenEndpoint(): OpenId4VciAccessTokenEndpointConfig;
    getUriStateManager(agentContext: AgentContext): IStateManager<URIState>;
    getCredentialOfferSessionStateManager(agentContext: AgentContext): IStateManager<CredentialOfferSession>;
    getCNonceStateManager(agentContext: AgentContext): IStateManager<CNonceState>;
}
